/***********************************************************************
 *
 *  Copyright 2001,2002 by FS-Forth Systeme GmbH.
 *  All rights reserved.
 *
 *  $Id: cmdopt.h,v 1.3 2007-08-16 12:51:35 mpietrek Exp $
 *  @Author: Markus Pietrek
 *  @Descr: Provides some helper functions to access the command line
 *          options. The results are stored in global variables.
 *  @Source: FS Forth CVS project LLIB (V_1_4)
 *  
 ********************************************************************** */
/*********************************************************************** *
 *  @History:
 *     2002/10/21 : Purified for splint. Changed to new variable naming
 *                  convention
 *********************************************************************** */

#ifndef FS_CMDOPT_H
#define FS_CMDOPT_H

/*@-exportlocal@*/ // this is a library include filed. some code may be unused

#ifdef __cplusplus
extern "C" {
#endif

typedef enum { COT_BOOL,        // if present,bool is set 1, otherwise unchanged
               COT_INT,         // sets *valuePtr to the int value
				// with conversions (if 0x
				// prefix is present)
               COT_STRING,      // sets *valuePtr to the string
               COT_MORE,        // to end the array. Any additional arguments
                                // are allowed
               COT_MORE_OPT,    // to end the array. Any optional arguments
                                // are allowed
               COT_NONE         // to end the array. Any additional arguments
                                // are considered as failures
} CmdOptTypes;

typedef struct
{
        CmdOptTypes type;       // type of option to be read
        signed char cOptChar;   // character to identify that option, if 0, then
                                // no option is used but parameter is required
        /*@exposed@*/
	/*@null@*/
        void*       vValuePtr;  // ptr to the variable where value is stored
        /*@observer@*/
        /*@null@*/
	const char* szLabelStr; // label displayed in command line
        /*@observer@*/
	/*@null@*/
	const char* szHelpStr;  // displays this help string for the variable
	/*@null@*/
        char*       pbPresent;  // will be set to if this option is present
} CmdOptEntry;


/*  can be set to display additional usage */
extern void (*fnCmdOptExtendedUsage) (char bCmdLine);

/*@observer@*/
extern const char* szCmdOptVersion; // overwrite it before calling cmdOptParse to
                                    // define version of application

/*@maynotreturn@*/
int cmdOptParse( int argc,
                 char* argv[],
                 const CmdOptEntry entries[],
                 const char* szDescr );

void cmdOptUsageAndExit(
        int argc,
        char* argv[],
        const CmdOptEntry entries[],
        const char* szDescr );

#ifdef __cplusplus
}
#endif

/*@+exportlocal@*/
#endif // FS_CMDOPT_H
