/***********************************************************************
 *
 *  Copyright 2001,2002 by FS-Forth Systeme GmbH.
 *  All rights reserved.
 *
 *  $Id: log.h,v 1.1 2006-11-30 10:39:01 mpietrek Exp $
 *  @Author: Markus Pietrek
 *  @Descr: Provides the logging facility for
 *          applications. The log level may
 *          be set at runtime. Syslog is not used
 *          as this would require syslogd to be
 *          running.
 *  
 ***********************************************************************/
/*********************************************************************** *
 *  @History:
 *     2002/10/21 : purified for splint, log renamed to logMsg
 *********************************************************************** */

#ifndef FS_LOG_H
#define FS_LOG_H

#ifdef __cplusplus
extern "C" {
#endif

/*@-exportlocal@*/ // this is a library include filed. some code may be unused

// each log message which is equal or lower
// is being printed
// LOG_LAST is used to determine last entry, new values should be added before
// it
// the log levels
typedef enum { LOG_ERR = 0, LOG_STATUS, LOG_HARDWARE1,
               LOG_HARDWARE2, LOG_PACKET, LOG_LAST } LogLevel;

extern LogLevel logLevel;


/*printflike*/
extern void logMsg( LogLevel level, const char* szFormat, ... )
/*@modifies stderr@*/;

extern void systemLog( const char* szFormat, ... )
/*@globals errno@*/
/*@modifies stderr@*/;

/*printflike*/
/*@noreturn@*/
extern void error( const char* szFormat, ... )
/*@modifies stderr@*/;

/*@noreturn@*/
extern void systemError( const char* szFormat, ... )
/*@globals errno@*/
/*@modifies stderr@*/;
#ifdef __cplusplus
}
#endif

/*@+exportlocal@*/
#endif // FS_LOG_H
